==> bundesliga-cli-0.2.0.tar.gz: bundesliga-cli-0.2.0/bundesliga/helpers.py <==
# -*- coding: utf-8 -*-

import datetime
import string

from prettytable import PrettyTable


def parseDateTime(time):
    return datetime.datetime.strptime(time, '%a, %d %b %Y %H:%M:%S %Z')

def from_utc(utcTime, fmt="%Y-%m-%dT%H:%M:%S.%fZ"):
    """
    Convert UTC ISO-8601 time string to time.struct_time
    """
    # change datetime.datetime to time, return time.struct_time type
    return datetime.datetime.strptime(utcTime, fmt)

def getYear(time):
    return datetime.datetime.stftime("%Y")

def create_results_table():
    x = PrettyTable(["Home", "Away", "Result", "Goals", "Status", "Date"])
    x.align["Home"] = "l"
    x.align["Away"] = "l"
    x.align["Date"] = "l"
    x.align["Goals"] = "l"
    return x


def create_table_table(rows):
    x = PrettyTable(["Rank", "Club", "Matches", "Wins", "Draws", "Losses", "Goals", "GD", "Points"], align="r")
    x.align["Rank"] = "r"
    x.align["Club"] = "l"
    x.align["Matches"] = "r"
    x.align["Wins"] = "r"
    x.align["Draws"] = "r"
    x.align["Losses"] = "r"
    x.align["GD"] = "r"
    x.align["Points"] = "r"

    for row in rows:
        x.add_row(row)

    return x


def create_leagues_table():
    x = PrettyTable(["Name", "Season", "Shortcut"])
    x.align["Name"] = "l"
    return x


def create_teams_table():
    x = PrettyTable(["Name"])
    x.align["Name"] = "l"
    return x


def current_season():
    return "2014"


def process_matches(matches):
    if not matches:
        return

    results = []
    for match in matches:
        match_result = []
        match = match['Matchdata']

        now = datetime.datetime.utcnow()
        okParsingMatchDate = False
        try:
            matchDate = parseDateTime(match['matchDateTimeUTC'])
            date = matchDate.strftime('%H:%M %d.%m.%Y')
            okParsingMatchDate = True
        except:
            date = "-"
            status = "-"

        if okParsingMatchDate:
            if matchDate > now:
                status = "Not started"
                points = "-:-"
            else:
                if match['matchIsFinished'] == True:
                    status = 'Finished'
                else:
                    status = 'Running'

        goalsInfo = ""
        if 'goals' in match and match['goals'] != None and len(match['goals']) > 0:
            goals = match['goals']
            for goal in goals:
                goal = goal['Goal']
                if 'goalGetterName' in goal:
                    scoreTeam1 = str(goal['goalScoreTeam1'])
                    scoreTeam2 = str(goal['goalScoreTeam2'])
                    goalsInfo += scoreTeam1 + ':' + scoreTeam2 + ' ' + goal['goalGetterName'] + ', '

            goalsInfo = goalsInfo[:-2]

            maxLength = 50
            if len(goalsInfo) > maxLength:
                index = string.rfind(goalsInfo[:maxLength-1], ',')
                while index < 0:
                    index = string.rfind(goalsInfo[:maxLength])
                    maxLength += 1
                goalsInfo = goalsInfo[:index] + '\n' + string.strip(goalsInfo[index+1:])

        points = '-:-'
        matchResults = match['matchResults']
        if len(matchResults) == 1:
            result = matchResults[0]['matchResult']
            points = str(result['pointsTeam1']) + " : " + str(result['pointsTeam2'])
        elif len(matchResults) >= 2:
            for entry in matchResults:
                result = entry['matchResult']
                if result['resultName'] == 'Endergebnis':
                    points = str(result['pointsTeam1']) + " : " + str(result['pointsTeam2'])
                    break

        match_result.append(match['nameTeam1'])
        match_result.append(match['nameTeam2'])
        match_result.append(points)
        match_result.append(goalsInfo)
        match_result.append(status)
        match_result.append(date)

        results.append(match_result)

    return results


def process_table_stats(stats):
    results = []

    rank = 1
    for club in stats:
        count_matches = club['wins'] + club['losses'] + club['draws']
        goals = str(club['goals']) + ':' + str(club['received_goals'])
        gd = int(club['goals']) - int(club['received_goals'])

        club_result = []
        club_result.append(rank)
        club_result.append(club['team_name'])
        club_result.append(count_matches)
        club_result.append(club['wins'])
        club_result.append(club['draws'])
        club_result.append(club['losses'])
        club_result.append(goals)
        club_result.append(gd)
        club_result.append(club['points'])

        rank += 1

        results.append(club_result)

    return results

==> bundesliga-cli-0.2.1.tar.gz: bundesliga-cli-0.2.1/bundesliga/helpers.py <==
# -*- coding: utf-8 -*-

from datetime import datetime
from dateutil import tz
import string

from prettytable import PrettyTable


from_zone = tz.tzutc()
to_zone = tz.tzlocal()


def getNow():
    utc = datetime.utcnow()
    utc = utc.replace(tzinfo=from_zone)
    return utc.astimezone(to_zone)

def parseDateTime(time):
    utc = datetime.strptime(time, '%a, %d %b %Y %H:%M:%S %Z')
    utc = utc.replace(tzinfo=from_zone)
    return utc.astimezone(to_zone)

def from_utc(utcTime, fmt="%Y-%m-%dT%H:%M:%S.%fZ"):
    """
    Convert UTC ISO-8601 time string to time.struct_time
    """
    # change datetime.datetime to time, return time.struct_time type
    return datetime.strptime(utcTime, fmt)

def getYear(time):
    return datetime.stftime("%Y")

def create_results_table():
    x = PrettyTable(["Home", "Away", "Result", "Goals", "Status", "Date"])
    x.align["Home"] = "l"
    x.align["Away"] = "l"
    x.align["Date"] = "l"
    x.align["Goals"] = "l"
    return x


def create_table_table(rows):
    x = PrettyTable(["Rank", "Club", "Matches", "Wins", "Draws", "Losses", "Goals", "GD", "Points"], align="r")
    x.align["Rank"] = "r"
    x.align["Club"] = "l"
    x.align["Matches"] = "r"
    x.align["Wins"] = "r"
    x.align["Draws"] = "r"
    x.align["Losses"] = "r"
    x.align["GD"] = "r"
    x.align["Points"] = "r"

    for row in rows:
        x.add_row(row)

    return x


def create_leagues_table():
    x = PrettyTable(["Name", "Season", "Shortcut"])
    x.align["Name"] = "l"
    return x


def create_teams_table():
    x = PrettyTable(["Name"])
    x.align["Name"] = "l"
    return x


def current_season():
    return "2014"


def process_matches(matches):
    if not matches:
        return

    results = []
    for match in matches:
        match_result = []
        match = match['Matchdata']

        now = getNow()
        okParsingMatchDate = False
        try:
            matchDate = parseDateTime(match['matchDateTimeUTC'])
            date = matchDate.strftime('%H:%M %d.%m.%Y')
            okParsingMatchDate = True
        except:
            date = "-"
            status = "-"

        if okParsingMatchDate:
            if matchDate > now:
                status = "Not started"
                points = "-:-"
            else:
                if match['matchIsFinished'] == True:
                    status = 'Finished'
                else:
                    status = 'Running'

        goalsInfo = ""
        if 'goals' in match and match['goals'] != None and len(match['goals']) > 0:
            goals = match['goals']
            for goal in goals:
                goal = goal['Goal']
                if 'goalGetterName' in goal:
                    scoreTeam1 = str(goal['goalScoreTeam1'])
                    scoreTeam2 = str(goal['goalScoreTeam2'])
                    goalsInfo += scoreTeam1 + ':' + scoreTeam2 + ' ' + goal['goalGetterName'] + ', '

            goalsInfo = goalsInfo[:-2]

            maxLength = 50
            if len(goalsInfo) > maxLength:
                index = string.rfind(goalsInfo[:maxLength-1], ',')
                while index < 0:
                    index = string.rfind(goalsInfo[:maxLength])
                    maxLength += 1
                goalsInfo = goalsInfo[:index] + '\n' + string.strip(goalsInfo[index+1:])

        points = '-:-'
        matchResults = getMatchResults(match['matchResults'])
        if len(matchResults) > 0:
            points = str(matchResults[0]) + " : " + str(matchResults[1])

        team1 = match['nameTeam1']
        team2 = match['nameTeam2']

        match_result.append(team1)
        match_result.append(team2)
        match_result.append(points)
        match_result.append(goalsInfo)
        match_result.append(status)
        match_result.append(date)

        results.append(match_result)

    return results


def process_table_stats(stats):
    results = []

    rank = 1
    for club in stats:
        count_matches = club['wins'] + club['losses'] + club['draws']
        goals = str(club['goals']) + ':' + str(club['received_goals'])
        gd = int(club['goals']) - int(club['received_goals'])

        club_result = []
        club_result.append(rank)
        club_result.append(club['team_name'])
        club_result.append(count_matches)
        club_result.append(club['wins'])
        club_result.append(club['draws'])
        club_result.append(club['losses'])
        club_result.append(goals)
        club_result.append(gd)
        club_result.append(club['points'])

        rank += 1

        results.append(club_result)

    return results


def getMatchResults(matchResults):
    """
    Returns a tuble with the match points for the given 'matchResult' data.

    'matchResult' is of the following form:

    "matchResults": [
      {
        "matchResult": {
          "pointsTeam1": 1,
          "pointsTeam2": 0,
          "resultName": "Halbzeitergebnis",
          "resultOrderID": 1,
          "resultTypeId": 1,
          "resultTypeName": "Halbzeit"
        }
      },
      {
        "matchResult": {
          "pointsTeam1": 5,
          "pointsTeam2": 0,
          "resultName": "Endergebnis",
          "resultOrderID": 2,
          "resultTypeId": 2,
          "resultTypeName": "nach 90 Minuten"
        }
      }
    ]
    """
    if len(matchResults) == 1:
        return (result['pointsTeam1'], result['pointsTeam2'])
    elif len(matchResults) >= 2:
        for entry in matchResults:
            result = entry['matchResult']
            if result['resultName'] == 'Endergebnis':
                return (result['pointsTeam1'], result['pointsTeam2'])

    return ()
